==> mikujs-1.3.1.tgz: package/lib/components/file.js <==
/**
 * 文件组件
 */
const fs = require('fs');

const _ = require('./lodash');

const ignoreFileArray = [
  '.DS_Store',
];

module.exports = {
  /**
   * 获取文件名
   * @param fileName
   * @returns {string}
   */
  name(fileName) {
    return fileName.substring(0, fileName.lastIndexOf('.'));
  },

  /**
   * 获取后缀名
   * @param fileName
   * @returns {string}
   */
  suffix(fileName) {
    return fileName.substring(fileName.lastIndexOf('.') + 1, fileName.length);
  },

  /**
   * 读取路径下所有文件并转换成对象，key为文件名，value为文件导出对象
   * @param path
   * @returns {Object}
   */
  convertToObject(path) {
    const obj = {};

    const files = fs.readdirSync(path);
    _.pullAll(files, ignoreFileArray);

    _.forEach(files, (f) => {
      const item = `${path}/${f}`;
      const stat = fs.statSync(item);

      if (stat.isDirectory()) {
        const array = this.convertToObject(item);

        _.forEach(array, (value, key) => {
          obj[key] = value;
        });
      } else {
        const key = this.name(f);
        obj[key] = require(`${path}/${f}`);
      }
    });

    return obj;
  },

  /**
   * 读取路径下所有文件并转换成数组
   * @param path
   * @returns {Array}
   */
  covertToArray(path) {
    const arr = [];

    const files = fs.readdirSync(path);
    _.pullAll(files, ignoreFileArray);

    _.forEach(files, (f) => {
      const item = `${path}/${f}`;
      const stat = fs.statSync(item);

      if (stat.isDirectory()) {
        const array = this.covertToArray(item);

        _.forEach(array, (value) => {
          arr.push(value);
        });
      } else {
        const file = require(`${path}/${f}`);
        arr.push(file);
      }
    });

    return arr;
  },

  /**
   * 删除
   * @param path
   */
  del(path) {
    fs.unlinkSync(path);
  },

  /**
   * 是否存在
   * @param path
   */
  exist(path) {
    fs.existsSync(path);
  },

  /**
   * 写入文件
   * @param path
   * @param data
   */
  write(path, data) {
    fs.writeFileSync(path, data);
  },

  /**
   * 读取文件
   * @param path
   */
  read(path) {
    return fs.readFileSync(path);
  },
};

==> mikujs-1.5.4.tgz: package/lib/components/file.js <==
/**
 * 文件组件
 */
const fs = require('fs');

const _ = require('./lodash');

const ignoreFileArray = [
  '.DS_Store',
];

module.exports = {
  /**
   * 获取文件名
   * @param fileName
   * @returns {string}
   */
  name(fileName) {
    return fileName.substring(0, fileName.lastIndexOf('.'));
  },

  /**
   * 获取后缀名
   * @param fileName
   * @returns {string}
   */
  suffix(fileName) {
    return fileName.substring(fileName.lastIndexOf('.') + 1, fileName.length);
  },

  /**
   * 读取路径下所有文件并转换成对象，key为文件名，value为文件导出对象
   * @param path
   * @returns {Object}
   */
  convertToObject(path) {
    const obj = {};

    const files = fs.readdirSync(path);
    _.pullAll(files, ignoreFileArray);

    _.forEach(files, (f) => {
      const item = `${path}/${f}`;
      const stat = fs.statSync(item);

      if (stat.isDirectory()) {
        const array = this.convertToObject(item);

        _.forEach(array, (value, key) => {
          obj[key] = value;
        });
      } else {
        const key = this.name(f);
        obj[key] = require(`${path}/${f}`);
      }
    });

    return obj;
  },

  /**
   * 读取路径下所有文件并转换成数组
   * @param path
   * @returns {Array}
   */
  covertToArray(path) {
    const arr = [];

    const files = fs.readdirSync(path);
    _.pullAll(files, ignoreFileArray);

    _.forEach(files, (f) => {
      const item = `${path}/${f}`;
      const stat = fs.statSync(item);

      if (stat.isDirectory()) {
        const array = this.covertToArray(item);

        _.forEach(array, (value) => {
          arr.push(value);
        });
      } else {
        const file = require(`${path}/${f}`);
        arr.push(file);
      }
    });

    return arr;
  },

  /**
   * 删除
   * @param path
   */
  del(path) {
    fs.unlinkSync(path);
  },

  /**
   * 是否存在
   * @param path
   */
  exist(path) {
    return fs.existsSync(path);
  },

  /**
   * 写入文件
   * @param path
   * @param data
   */
  write(path, data) {
    fs.writeFileSync(path, data);
  },

  /**
   * 读取文件
   * @param path
   */
  read(path) {
    return fs.readFileSync(path);
  },

  /**
   * 修改权限
   * @param path
   * @param mode
   */
  chmod(path, mode) {
    fs.chmodSync(path, mode);
  },
};
